@@ -3,9 +3,8 @@ class TiDBCloudException(Exception):
 
 
 class TiDBCloudResponseException(TiDBCloudException):
-    def __init__(self, status, code=None, message=None, raw=None):
+    def __init__(self, status, message=None, raw=None):
         self._status = status
-        self._code = code
         self._message = message
         self._raw = raw
 
@@ -13,10 +12,6 @@ class TiDBCloudResponseException(TiDBCloudException):
     def status(self):
         return self._status
 
-    @property
-    def code(self):
-        return self._code
-
     @property
     def message(self):
         return self._message
@@ -26,4 +21,4 @@ class TiDBCloudResponseException(TiDBCloudException):
         return self._raw
 
     def __str__(self):
-        return "status: {}, code: {}, message: {}".format(self._status, self._code, self._message)
+        return "status: {}, message: {}".format(self._status, self._message)
