@@ -1,4 +1,4 @@
-from typing import TypeVar, Generic, List
+from typing import Generic, List, TypeVar
 
 T = TypeVar('T')
 
